@@ -1,4 +1,4 @@
-/*$Id: RulesParser.cpp,v 1.12 2006/08/20 21:03:03 jwrobel Exp $*/
+/*$Id: RulesParser.cpp,v 1.13 2006/08/21 10:13:44 jwrobel Exp $*/
 /* ***** BEGIN LICENSE BLOCK *****
  *  This file is part of Firekeeper.
  *
@@ -60,11 +60,14 @@ void RulesParser::err_append(const char *fmt, ...)
 	char buf[ERRBUFLEN];
 	va_list ap;
 	va_start(ap, fmt);
-	vsprintf(buf, fmt, ap);
+	vsnprintf(buf, ERRBUFLEN, fmt, ap);
 	va_end(ap);
+	int l;
 	
-	strncat(errmsg, buf, ERRBUFLEN - strlen(errmsg));
-	strncat(errmsg, "\n", ERRBUFLEN - strlen(errmsg));
+	if ((l = ERRBUFLEN - strlen(errmsg)) > 1)
+		strncat(errmsg, buf, l);
+	if ((l = ERRBUFLEN - strlen(errmsg)) > 1)
+		strncat(errmsg, "\n", l);
 	errmsg[ERRBUFLEN - 1] = 0;
 }
 
@@ -861,8 +864,10 @@ void RulesParser::parseLine(Rules *rules, char *line, int linenr)
 	
 	newRule = parseRule(line, &error);
 	
-	if (error)
+	if (error){
 		err_append("Error at line %d: %s", linenr, error);
+		TRACE("error = %s", error);
+	}
 	else
 		rules->addRule(newRule);
 	
@@ -876,7 +881,7 @@ void RulesParser::parseLine(Rules *rules, char *line, int linenr)
   @error - pointer to an error message buffer or NULL if there is no error.
            Error message is a static buffer which shouldn't
            be freed. If some rules have incorrect syntax, this 
-	   routine creates suitable error message, but rules
+x	   routine creates suitable error message, but rules
 	   that are correct are returned anyway.
   @return - 
  */
@@ -917,8 +922,7 @@ void RulesParser::parseRules(Rules *rules, const char *input, char **error)
 	
 	       
 	if (strlen(errmsg) == 0)
-	    *error = NULL;
-
+		*error = NULL;
 }
 
 
